﻿using System;
using System.Diagnostics;
using System.Threading.Tasks;
using Warden.Watchers;

namespace ProcessWatcher
{
    public class ProcessWatcher : IWatcher
    {
        private readonly string _processName;
        public string Name { get; } = "Process Watcher";

        public ProcessWatcher(string processName)
        {
            if(string.IsNullOrWhiteSpace(processName))
                throw new ArgumentException("Process name can not be empty", nameof(processName));

            _processName = processName;
        }

        public async Task<IWatcherCheckResult> ExecuteAsync()
        {
            var process = Process.GetProcessesByName(_processName);
            var isRunning = process.Length > 0;
            var description = $"Process '{_processName}' is {(isRunning ? string.Empty : "not ")}running.";
            var result = new ProcessWatcherCheckResult(this, _processName, isRunning, description);

            return await Task.FromResult(result);
        }
    }
}